==> rc-ui-lib-0.1.29.tgz: package/es/empty/Empty.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { isValidElement } from 'react';
import classnames from 'classnames';
import { createNamespace, getSizeStyle } from '../utils';
import { Network } from './Network';
var PRESET_IMAGES = ['error', 'search', 'default'];

var _createNamespace = createNamespace('empty'),
    _createNamespace2 = _slicedToArray(_createNamespace, 1),
    bem = _createNamespace2[0];

var Empty = function Empty(props) {
  var renderImage = function renderImage() {
    var image = props.image;

    if ( /*#__PURE__*/isValidElement(image)) {
      return image;
    }

    if (image === 'network') {
      return Network;
    }

    if (PRESET_IMAGES.includes(image)) {
      image = "https://img.yzcdn.cn/vant/empty-image-".concat(image, ".png");
    }

    return /*#__PURE__*/React.createElement("img", {
      src: image,
      alt: ""
    });
  };

  var renderDescription = function renderDescription() {
    if (props.description) {
      return /*#__PURE__*/React.createElement("p", {
        className: classnames(bem('description'))
      }, props.description);
    }

    return null;
  };

  var renderBottom = function renderBottom() {
    if (props.children) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('bottom'))
      }, props.children);
    }

    return null;
  };

  return /*#__PURE__*/React.createElement("div", {
    className: classnames(props.className, bem()),
    style: props.style
  }, /*#__PURE__*/React.createElement("div", {
    className: classnames(bem('image')),
    style: getSizeStyle(props.imageSize)
  }, renderImage()), renderDescription(), renderBottom());
};

Empty.defaultProps = {
  image: 'default'
};
export default Empty;

==> rc-ui-lib-0.1.41.tgz: package/es/empty/Empty.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { isValidElement, useContext } from 'react';
import classnames from 'classnames';
import { getSizeStyle } from '../utils';
import { Network } from './Network';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var PRESET_IMAGES = ['error', 'search', 'default'];

var Empty = function Empty(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('empty', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var renderImage = function renderImage() {
    var image = props.image;

    if ( /*#__PURE__*/isValidElement(image)) {
      return image;
    }

    if (image === 'network') {
      return Network;
    }

    if (PRESET_IMAGES.includes(image)) {
      image = "https://img.yzcdn.cn/vant/empty-image-".concat(image, ".png");
    }

    return /*#__PURE__*/React.createElement("img", {
      src: image,
      alt: ""
    });
  };

  var renderDescription = function renderDescription() {
    if (props.description) {
      return /*#__PURE__*/React.createElement("p", {
        className: classnames(bem('description'))
      }, props.description);
    }

    return null;
  };

  var renderBottom = function renderBottom() {
    if (props.children) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('bottom'))
      }, props.children);
    }

    return null;
  };

  return /*#__PURE__*/React.createElement("div", {
    className: classnames(props.className, bem()),
    style: props.style
  }, /*#__PURE__*/React.createElement("div", {
    className: classnames(bem('image')),
    style: getSizeStyle(props.imageSize)
  }, renderImage()), renderDescription(), renderBottom());
};

Empty.defaultProps = {
  image: 'default'
};
export default Empty;
